/** ZCT/globals.h--Created 070105 **/

/** Copyright 2008 Zach Wegner **/
/*
 * This file is part of ZCT.
 *
 * ZCT is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 *
 * ZCT is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with ZCT.  If not, see <http://www.gnu.org/licenses/>.
 */
#include "zct.h"

#ifndef GLOBALS_H
#define GLOBALS_H

extern int singular_extension;
extern int singular_margin;
/* board representation */
extern BOARD board;
extern int process_count;

/* various board data */
extern const int pawn_dir[2];
extern const CASTLE_RIGHTS castle_rights_mask[64];
extern BITBOARD mask_bb[64];
extern BITBOARD pawn_caps_bb[2][64];
extern BITBOARD knight_moves_bb[64];
extern BITBOARD king_moves_bb[64];
extern BITBOARD in_between_bb[64][64];
extern BITBOARD castle_ks_mask[2];
extern BITBOARD castle_qs_mask[2];
extern HASHKEY zobrist_piece[2][6][64];
extern HASHKEY zobrist_castle[16];
extern HASHKEY zobrist_ep[65];
extern HASHKEY zobrist_stm;

/* interface data */
extern PROTOCOL protocol;
extern NOTATION notation;
extern FILE *input_stream;
extern FILE *output_stream;
extern FILE *log_stream;
extern BOOL source;
extern char input_buffer[BUFSIZ];
extern BOOL use_book;
extern BOOL post;
extern int output_limit;
extern BOOL hard;
extern int ping;
extern BOOL ics_mode;

/* statistics and search data */
extern ENGINE_STATE engine_state;
extern COLOR zct_side;
extern BOOL game_over;
extern RESULT game_result;
extern MOVE ponder_move;
extern int search_age;
extern int max_depth;
extern int max_nodes;
extern int current_depth;
extern GAME_ENTRY *root_entry;
extern ROOT_MOVE *next_root_move;
extern ROOT_MOVE root_move_list[MAX_ROOT_MOVES];
extern int root_move_count;
extern int root_pv_counter;
extern VALUE last_root_score;
extern VALUE best_score_by_depth[MAX_PLY];
extern int pv_changes_by_depth[MAX_PLY];
extern BITBOARD nodes;
extern BITBOARD q_nodes;
extern int max_depth_reached;
extern int nodes_per_check;
extern int nodes_until_check;
extern int sb_id;
extern BITBOARD pv_nodes;
extern BITBOARD fail_high_nodes;
extern BITBOARD fail_low_nodes;
extern BITBOARD pv_first;
extern BITBOARD fail_high_first;
extern BITBOARD hash_probes;
extern BITBOARD hash_hits;
extern BITBOARD hash_cutoffs;
extern BITBOARD hash_entries_full;
extern BITBOARD pawn_hash_probes;
extern BITBOARD pawn_hash_hits;
extern BITBOARD eval_hash_probes;
extern BITBOARD eval_hash_hits;
extern BITBOARD qsearch_hash_probes;
extern BITBOARD qsearch_hash_hits;
extern unsigned int history_counter;
extern unsigned int history_table[2][4096];
extern MOVE killer_move[MAX_PLY][2];
extern MOVE counter_move[2][4096][2];
extern int history_threshold;
extern int check_extension;
extern int one_rep_extension;
extern int threat_extension;
extern int passed_pawn_extension;
extern int check_extensions_done;
extern int one_rep_extensions_done;
extern int threat_extensions_done;
extern int passed_pawn_extensions_done;
extern int singular_extensions_done;
extern BITBOARD hash_size;
extern unsigned int qsearch_hash_size;
extern unsigned int pawn_hash_size;
extern unsigned int eval_hash_size;
extern HASH_ENTRY *hash_table;
extern HASH_ENTRY *qsearch_hash_table;
extern PAWN_HASH_ENTRY *pawn_hash_table;
extern EVAL_HASH_ENTRY *eval_hash_table;

/* other constants */
extern const char color_str[2][6];
extern const char piece_char[2][7];
extern const char piece_str[6][7];
extern const char result_str[][64];

#endif /* GLOBALS_H */
